docs.rs failed to build hip-sys-0.1.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
hip-sys-0.1.1
hip-sys
Rust bindings for HIP
Dependencies
- A ROCm platform ie a compatible AMD GPU
hipblascan be accessed with theblasfeature- Specify the path to
hipwithHIP_PATH. If not provided,hipconfig -pis tried or/opt/rocm/hipis assumed - Specify the path to
hipblaswithHIP_BLAS_PATH. If not provided,/opt/rocm/hipblasis assumed - Native bindings can be generated with the
bindgenfeature - Will compile without an AMD GPU, but device functions will fail
- Currently CUDA platform support is not available (see cuda-sys https://github.com/rust-cuda/cuda-sys)
Install ROCm
- Ubuntu: See https://rocmdocs.amd.com/en/latest/deploy/linux/quick_start.html
- Works with the hcc backend
sudo apt install hip-hcc(from ROCm package registry)
- You may need to install rocsolver as well
sudo apt install rocsolver
- Works with the hcc backend
- Arch: See https://github.com/arch4edu/arch4edu
sudo pacman -S rocm-hip-runtime
If you have any problems please post an issue.
Tests
Run the tests with:
cargo test
Docs
Open the documentation with:
cargo doc --open
Acknowledgement
This repo is derived from one created here; permission has been gained to publish this work with local modifications (see issue #1).