hip-sys 0.1.2

Bindings for HIP
docs.rs failed to build hip-sys-0.1.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: hip-sys-0.1.1

hip-sys

Rust bindings for HIP

Dependencies

  • A ROCm platform ie a compatible AMD GPU
    • hipblas can be accessed with the blas feature
    • Specify the path to hip with HIP_PATH. If not provided, hipconfig -p is tried or /opt/rocm/hip is assumed
    • Specify the path to hipblas with HIP_BLAS_PATH. If not provided, /opt/rocm/hipblas is assumed
    • Native bindings can be generated with the bindgen feature
    • Will compile without an AMD GPU, but device functions will fail
    • Currently CUDA platform support is not available (see cuda-sys https://github.com/rust-cuda/cuda-sys)

Install ROCm

If you have any problems please post an issue.

Tests

Run the tests with:

cargo test

Docs

Open the documentation with:

cargo doc --open

Acknowledgement

This repo is derived from one created here; permission has been gained to publish this work with local modifications (see issue #1).